@@ -1,6 +1,6 @@
 # LatticeKrig  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2016
+# Copyright (C) 2024
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -53,11 +53,11 @@ summary.LKrig <- function(object, digits = 4, stripAwght=TRUE, ...) {
   c1 <- c(c1, "Smoothing parameter (lambda)")
   c2 <- c(c2, signif(x$lambda, digits))
   
-  c1 <- c(c1, "MLE sigma ")
-  c2 <- c(c2, signif(x$sigma.MLE.FULL, digits))
+  c1 <- c(c1, "MLE tau ")
+  c2 <- c(c2, signif(x$tau.MLE.FULL, digits))
   
-  c1 <- c(c1, "MLE rho")
-  c2 <- c(c2, signif(x$rho.MLE.FULL, digits))
+  c1 <- c(c1, "MLE sigma2")
+  c2 <- c(c2, signif(x$sigma2.MLE.FULL, digits))
 
   
   c1 <- c(c1, "Total number of basis functions")
@@ -91,6 +91,28 @@ summary.LKrig <- function(object, digits = 4, stripAwght=TRUE, ...) {
   }
   obj$LKinfo<- LKinfo
   obj$MLE<- x$MLE
+  ##### table of fixed model coefficients along the style of 
+  ###### lm
+  d.coef<-object$d.coef 
+  nP<- nrow(d.coef )
+  nReps<- ncol(d.coef)
+  if( nReps==1){
+  coefficients <- matrix(NA, ncol=4, nrow=nP )
+  colnames( coefficients)<-  
+              c("Estimate", "Std. Error", "t value", "Pr(>|t|)"  )
+  rownames( coefficients)<- rownames( object$d.coef)
+  
+  coefficients[,1]<- d.coef
+  SE<- sqrt(object$sigma2.MLE* diag( object$Omega))
+  coefficients[,2]<- SE
+  coefficients[,3]<- d.coef/SE
+  df<-  object$n  - nP
+  coefficients[,4]<- 2 * pt( abs(d.coef/SE), df, lower.tail=FALSE )
+  }
+  else{
+    coefficients<- NA
+  }
+  obj$coefficients<- coefficients
   return(obj)
 }
 
